Use a timer in SensorReader

Since we know what time the next iteration should occur at,
it makes more sense to set a timer for that time instead of
modifying the PhasedLoop's offset.

Change-Id: Iddacb4726ea7278d910ba15e7780ebcad76b7858
Signed-off-by: milind-u <milind.upadhyay@gmail.com>
diff --git a/frc971/wpilib/sensor_reader.h b/frc971/wpilib/sensor_reader.h
index 8efdf75..5ae7ffd 100644
--- a/frc971/wpilib/sensor_reader.h
+++ b/frc971/wpilib/sensor_reader.h
@@ -221,7 +221,7 @@
   void DoStart();
 
   // Runs a single iteration.
-  void Loop(int iterations);
+  void Loop();
 
   // Returns the monotonic time of the start of the first PWM cycle.
   // Returns min_time if no start time could be calculated.
@@ -236,8 +236,8 @@
 
   const int32_t my_pid_;
 
-  // Pointer to the phased loop handler used to modify the wakeup.
-  ::aos::PhasedLoopHandler *phased_loop_handler_;
+  // Pointer to the timer handler used to modify the wakeup.
+  ::aos::TimerHandler *timer_handler_;
 
   // Last time we got called.
   ::aos::monotonic_clock::time_point last_monotonic_now_ =